@@ -1,6 +1,6 @@
 package Mercury;
 # ABSTRACT: Main broker application class
-$Mercury::VERSION = '0.007';
+$Mercury::VERSION = '0.008';
 
 use Mojo::Base 'Mojolicious';
 use Scalar::Util qw( refaddr );
@@ -188,7 +188,7 @@ Mercury - Main broker application class
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 DESCRIPTION
 
@@ -205,12 +205,12 @@ run C<mercury help broker>.
 
 =head2 /bus/*topic
 
-Establish a WebSocket message bus to send/recieve messages on the given
+Establish a WebSocket message bus to send/receive messages on the given
 C<topic>. All clients connected to the topic will receive all messages
 published on the topic.
 
 This is a shorter way of doing both C</pub/*topic> and C</sub/*topic>,
-without the hierarchal message passing.
+without the hierarchical message passing.
 
 One difference is that by default a sender will not receive a message
 that they sent. To enable this behavior, pass a true value as the C<echo>
@@ -269,7 +269,7 @@ child topics as well.
 
 =head2 remove_topic_subscriber
 
-    $c->remote_topic_subscriber( $topic );
+    $c->remove_topic_subscriber( $topic );
 
 Remove the current connection from the given topic. Must be called to clean up
 the state.
